%if 0%{?fedora} || 0%{?rhel} == 6
%global with_devel 1
%global with_bundled 0
%global with_debug 0
%global with_check 1
%global with_unit_test 1
%else
%global with_devel 0
%global with_bundled 0
%global with_debug 0
%global with_check 0
%global with_unit_test 0
%endif

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         hashicorp
%global repo            hcl
# https://github.com/hashicorp/hcl
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          2deb1d1db27ed473f38fe65a16044572b9ff9d30
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0
Release:        0.7.git%{shortcommit}%{?dist}
Summary:        HCL is a configuration language
License:        MPLv2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
BuildRequires: golang(github.com/hashicorp/go-multierror)
%endif

Requires:      golang(github.com/hashicorp/go-multierror)

Provides:      golang(%{import_path}) = %{version}-%{release}
Provides:      golang(%{import_path}/hcl) = %{version}-%{release}
Provides:      golang(%{import_path}/json) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%package unit-test
Summary:         Unit tests for %{name} package
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}

%build

%install
# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . -iname "*.go" \! -iname "*_test.go") ; do
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list
done
%endif

# testing files for this project
%if 0%{?with_unit_test} && 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test.file-list
for file in $(find . -iname "*_test.go"); do
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
echo "%%{gopath}/src/%%{import_path}/test-fixtures" >> unit-test.file-list
cp -r ./test-fixtures %{buildroot}/%{gopath}/src/%{import_path}/.

echo "%%{gopath}/src/%%{import_path}/hcl/parser/test-fixtures" >> unit-test.file-list
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/hcl/parser
cp -r ./hcl/parser/test-fixtures %{buildroot}/%{gopath}/src/%{import_path}/hcl/parser/.
echo "%%{gopath}/src/%%{import_path}/hcl/printer/testdata" >> unit-test.file-list
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/hcl/printer
cp -r ./hcl/printer/testdata %{buildroot}/%{gopath}/src/%{import_path}/hcl/printer/.

echo "%%{gopath}/src/%%{import_path}/json/parser/test-fixtures" >> unit-test.file-list
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/json/parser
cp -r ./json/parser/test-fixtures %{buildroot}/%{gopath}/src/%{import_path}/json/parser/.

%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}
%gotest %{import_path}/hcl/ast
%gotest %{import_path}/hcl/parser
%gotest %{import_path}/hcl/printer
%gotest %{import_path}/hcl/scanner
%gotest %{import_path}/hcl/strconv
%gotest %{import_path}/hcl/token
%gotest %{import_path}/json/parser
%gotest %{import_path}/json/scanner
%gotest %{import_path}/json/token
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE
%doc README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%files unit-test -f unit-test.file-list
%license LICENSE
%doc README.md
%endif

%changelog
* Mon Feb 22 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.7.git2deb1d1
- https://fedoraproject.org/wiki/Changes/golang1.6

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0-0.6.git2deb1d1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 13 2016 jchaloup <jchaloup@redhat.com> - 0-0.5.git2deb1d1
- Copy missing directories with test data and run removed tests
  related: #1250468

* Wed Jan 06 2016 Fridolin Pokorny <fpokorny@redhat.com> - 0-0.4.git2deb1d1
- Bump to upstream 2deb1d1db27ed473f38fe65a16044572b9ff9d30
  Removed deleted tests
  related: #1250468

* Sat Sep 12 2015 jchaloup <jchaloup@redhat.com> - 0-0.3.git513e04c
- Update to spec-2.1
  related: #1250468

* Wed Aug 05 2015 Fridolin Pokorny <fpokorny@redhat.com> - 0-0.2.git513e04c
- Update spec file to spec-2.0
  resolves: #1250468

* Wed Apr 15 2015 jchaloup <jchaloup@redhat.com> - 0-0.1.git513e04c
- First package for Fedora
  resolves: #1212059

